@@ -8,7 +8,6 @@ Situations tested:
 """
 from pathlib import Path
 
-
 folder = Path(__file__).resolve().parents[1]
 changelog = Path(folder, "docs", "CHANGELOG.rst")
 
@@ -20,5 +19,5 @@ with open(changelog, "r") as fin:
                 "As described in: https://python-project-skeleton.readthedocs.io"
                 "/en/latest/contributing.html#update-changelog."
             )
-        elif line.startswith("*"):
+        if line.startswith("*"):
             break
