@@ -1,18 +1,15 @@
 # -*- coding: utf-8 -*-
 """Collection of functions for the manipulation of time series."""
 
-from __future__ import absolute_import, division, print_function
-
 import warnings
 
-import mando
+import cltoolbox
 import numpy as np
 import typic
-from mando.rst_text_formatter import RSTHelpFormatter
+from cltoolbox.rst_text_formatter import RSTHelpFormatter
 
 from .. import tsutils
 
-
 try:
     from typing import Literal
 except ImportError:
@@ -35,29 +32,26 @@ def _boolrelextrema(
     ----------
     data: ndarray
     comparator: function
-        function to use to compare two data points.
-        Should take 2 numbers as arguments
+        function to use to compare two data points.  Should take 2 numbers as
+        arguments
     axis: int, optional
         axis over which to select from `data`
     order: int, optional
-        How many points on each side to require
-        a `comparator`(n,n+x) = True.
+        How many points on each side to require a `comparator`(n,n+x) = True.
     mode: string, optional
-        How the edges of the vector are treated.
-        'wrap' (wrap around) or 'clip' (treat overflow
-        as the same as the last (or first) element).
+        How the edges of the vector are treated.  'wrap' (wrap around) or
+        'clip' (treat overflow as the same as the last (or first) element).
         Default 'clip'. See numpy.take
 
     Returns
     -------
     extrema: ndarray
-        Indices of the extrema, as boolean array
-        of same shape as data. True for an extrema,
-        False else.
+        Indices of the extrema, as boolean array of same shape as data. True
+        for an extrema, False else.
 
-    See also
+    See Also
     --------
-    argrelmax,argrelmin
+    argrelmax, argrelmin
 
     Examples
     --------
@@ -94,9 +88,9 @@ def _argrel(data, axis=0, window=1):
 def _argrelmin(data, axis=0, order=1, mode="clip"):
     """Calculate the relative minima of `data`.
 
-    See also
+    See Also
     --------
-    argrelextrema,argrelmax
+    argrelextrema, argrelmax
 
     """
     return _argrelextrema(data, np.less, axis, order, mode)
@@ -105,9 +99,9 @@ def _argrelmin(data, axis=0, order=1, mode="clip"):
 def _argrelmax(data, axis=0, order=1, mode="clip"):
     """Calculate the relative maxima of `data`.
 
-    See also
+    See Also
     --------
-    argrelextrema,argrelmin
+    argrelextrema, argrelmin
 
     """
     return _argrelextrema(data, np.greater, axis, order, mode)
@@ -122,7 +116,7 @@ def _argrelextrema(data, comparator, axis=0, order=1, mode="clip"):
         Indices of the extrema, as an array
         of integers (same format as argmin, argmax
 
-    See also
+    See Also
     --------
     argrelmin, argrelmax
 
@@ -130,8 +124,7 @@ def _argrelextrema(data, comparator, axis=0, order=1, mode="clip"):
     results = _boolrelextrema(data, comparator, axis, order, mode)
     if ~results.any():
         return (np.array([]),) * 2
-    else:
-        return np.where(results)
+    return np.where(results)
 
 
 def _datacheck_peakdetect(x_axis, y_axis):
@@ -142,12 +135,10 @@ def _datacheck_peakdetect(x_axis, y_axis):
     if len(y_axis) != len(x_axis):
         raise ValueError(
             tsutils.error_wrapper(
-                """
+                f"""
 The length of y values must equal the length of x values.  Instead the
-length of y values is {0} and the length of x values is {1}.
-""".format(
-                    len(y_axis), len(x_axis)
-                )
+length of y values is {len(y_axis)} and the length of x values is {len(x_axis)}.
+"""
             )
         )
 
@@ -266,33 +257,35 @@ def _peakdetect(
             mnpos = x
 
         # ####look for max####
-        if y < mx - delta and mx != np.Inf:
-            # Maxima peak candidate found
-            # look ahead in signal to ensure that this is a peak and not jitter
-            if y_axis[index : index + window].max() < mx:
-                max_peaks.append([mxpos, mx])
-                dump.append(True)
-                # set algorithm to only find minima now
-                mx = np.Inf
-                mn = np.Inf
-                if index + window >= length:
-                    # end is within window no more peaks can be found
-                    break
-                continue
+        if (
+            y < mx - delta
+            and mx != np.Inf
+            and y_axis[index : index + window].max() < mx
+        ):
+            max_peaks.append([mxpos, mx])
+            dump.append(True)
+            # set algorithm to only find minima now
+            mx = np.Inf
+            mn = np.Inf
+            if index + window >= length:
+                # end is within window no more peaks can be found
+                break
+            continue
 
         # ####look for min####
-        if y > mn + delta and mn != -np.Inf:
-            # Minima peak candidate found
-            # look ahead in signal to ensure that this is a peak and not jitter
-            if y_axis[index : index + window].min() > mn:
-                min_peaks.append([mnpos, mn])
-                dump.append(False)
-                # set algorithm to only find maxima now
-                mn = -np.Inf
-                mx = -np.Inf
-                if index + window >= length:
-                    # end is within window no more peaks can be found
-                    break
+        if (
+            y > mn + delta
+            and mn != -np.Inf
+            and y_axis[index : index + window].min() > mn
+        ):
+            min_peaks.append([mnpos, mn])
+            dump.append(False)
+            # set algorithm to only find maxima now
+            mn = -np.Inf
+            mx = -np.Inf
+            if index + window >= length:
+                # end is within window no more peaks can be found
+                break
 
     # Remove the false hit on the first value of the y_axis
     try:
@@ -300,7 +293,6 @@ def _peakdetect(
             max_peaks.pop(0)
         else:
             min_peaks.pop(0)
-        del dump
     except IndexError:
         # no peaks were found, should the function return empty lists?
         pass
@@ -388,8 +380,6 @@ def _peakdetect_fft(y_axis, x_axis, pad_len=5):
     max_peaks, min_peaks = _peakdetect(
         y_axis_ifft, x_axis_ifft, 500, delta=abs(np.diff(y_axis).max() * 2)
     )
-    # max_peaks, min_peaks = _peakdetect_zero_crossing(y_axis_ifft,
-    # x_axis_ifft)
 
     return [max_peaks, min_peaks]
 
@@ -440,9 +430,7 @@ def _peakdetect_parabola(y_axis, x_axis, points=9):
     min_ = _peakdetect_parabola_fitter(min_raw, x_axis, y_axis, points)
 
     max_peaks = [[x[0], x[1]] for x in max_]
-    # max_fitted = map(lambda x: x[-1], max_)
     min_peaks = [[x[0], x[1]] for x in min_]
-    # min_fitted = map(lambda x: x[-1], min_)
 
     return [max_peaks, min_peaks]
 
@@ -527,8 +515,6 @@ def _peakdetect_sine(y_axis, x_axis, points=9, lock_frequency=False):
         def func(x, a, hz, tau):
             return a * np.sin(2 * np.pi * hz * (x - tau) + (np.pi // 2))
 
-    # func = lambda x, a, hz, tau: a * np.cos(2 * np.pi * hz * (x - tau))
-
     # get peaks
     fitted_peaks = []
     for raw_peaks in [max_raw, min_raw]:
@@ -570,9 +556,7 @@ def _peakdetect_sine(y_axis, x_axis, points=9, lock_frequency=False):
 
     # structure date for output
     max_peaks = [[xval[0], xval[1]] for xval in fitted_peaks[0]]
-    # max_fitted = map(lambda x: x[-1], fitted_peaks[0])
     min_peaks = [[xval[0], xval[1]] for xval in fitted_peaks[1]]
-    # min_fitted = map(lambda x: x[-1], fitted_peaks[1])
 
     return [max_peaks, min_peaks]
 
@@ -657,18 +641,29 @@ def _peakdetect_zero_crossing(y_axis, x_axis=None, window=5):
         hi_peaks = [bin.max() for bin in even_bins_y]
         lo_peaks = [bin.min() for bin in odd_bins_y]
         # get x values for peak
-        for bin_x, bin_y, peak in zip(even_bins_x, even_bins_y, hi_peaks):
-            hi_peaks_x.append(bin_x[np.where(bin_y == peak)[0][0]])
-        for bin_x, bin_y, peak in zip(odd_bins_x, odd_bins_y, lo_peaks):
-            lo_peaks_x.append(bin_x[np.where(bin_y == peak)[0][0]])
+        hi_peaks_x.extend(
+            bin_x[np.where(bin_y == peak)[0][0]]
+            for bin_x, bin_y, peak in zip(even_bins_x, even_bins_y, hi_peaks)
+        )
+
+        lo_peaks_x.extend(
+            bin_x[np.where(bin_y == peak)[0][0]]
+            for bin_x, bin_y, peak in zip(odd_bins_x, odd_bins_y, lo_peaks)
+        )
+
     else:
         hi_peaks = [bin.max() for bin in odd_bins_y]
         lo_peaks = [bin.min() for bin in even_bins_y]
         # get x values for peak
-        for bin_x, bin_y, peak in zip(odd_bins_x, odd_bins_y, hi_peaks):
-            hi_peaks_x.append(bin_x[np.where(bin_y == peak)[0][0]])
-        for bin_x, bin_y, peak in zip(even_bins_x, even_bins_y, lo_peaks):
-            lo_peaks_x.append(bin_x[np.where(bin_y == peak)[0][0]])
+        hi_peaks_x.extend(
+            bin_x[np.where(bin_y == peak)[0][0]]
+            for bin_x, bin_y, peak in zip(odd_bins_x, odd_bins_y, hi_peaks)
+        )
+
+        lo_peaks_x.extend(
+            bin_x[np.where(bin_y == peak)[0][0]]
+            for bin_x, bin_y, peak in zip(even_bins_x, even_bins_y, lo_peaks)
+        )
 
     # peaks or valley cannot be at 0
     max_peaks = [[x, y] for x, y in zip(hi_peaks_x, hi_peaks) if x != 0]
@@ -714,7 +709,7 @@ def _smooth(
 
     See Also
     --------
-    numpy.hanning, numpy.hamming, numpy.bartlett, numpy.blackman,
+    numpy.hanning, numpy.hamming, numpy.bartlett, numpy.blackman
     numpy.convolve, scipy.signal.lfilter
 
     """
@@ -728,14 +723,12 @@ def _smooth(
         return x
 
     s = np.r_[x[window_len - 1 : 0 : -1], x, x[-1:-window_len:-1]]
-    # print(len(s))
     if window == "flat":  # moving average
         w = np.ones(window_len, "d")
     else:
-        w = eval("np." + window + "(window_len)")
+        w = eval(f"np.{window}(window_len)")
 
-    y = np.convolve((w / w.sum()), s, mode="valid")
-    return y
+    return np.convolve((w / w.sum()), s, mode="valid")
 
 
 def zero_crossings(y_axis, window=11):
@@ -761,8 +754,8 @@ def zero_crossings(y_axis, window=11):
 
     # discard tail of smoothed signal
     y_axis = _smooth(y_axis, window)[:length]
-    zero_crossings = np.where(np.diff(np.sign(y_axis)))[0]
-    indices = [x_axis[index] for index in zero_crossings]
+    nzero_crossings = np.where(np.diff(np.sign(y_axis)))[0]
+    indices = [x_axis[index] for index in nzero_crossings]
 
     # check if zero-crossings are valid
     # diff = np.diff(indices)
@@ -773,7 +766,7 @@ def zero_crossings(y_axis, window=11):
     #            "False zero-crossings found, indicates problem {0} or {1}".format(
     #            "with smoothing window", "problem with offset"))
     # check if any zero crossings were found
-    if len(zero_crossings) < 1:
+    if len(nzero_crossings) < 1:
         raise ValueError
 
     try:
@@ -799,7 +792,7 @@ def zero_crossings(y_axis, window=11):
 ##############################################################################
 
 
-@mando.command("peak_detection", formatter_class=RSTHelpFormatter, doctype="numpy")
+@cltoolbox.command("peak_detection", formatter_class=RSTHelpFormatter)
 @tsutils.doc(tsutils.docstrings)
 def peak_detection_cli(
     input_ts="-",
@@ -870,22 +863,21 @@ def peak_detection_cli(
         For 'sine' method only.  Specifies if the frequency argument of
         the model function should be locked to the value calculated from
         the raw peaks or if optimization process may tinker with it.
-    {input_ts}
-    {columns}
-    {start_date}
-    {end_date}
-    {dropna}
-    {skiprows}
-    {index_type}
-    {names}
-    {clean}
-    {float_format}
-    {round_index}
-    {source_units}
-    {target_units}
-    {print_input}
-    {tablefmt}
-
+    ${input_ts}
+    ${columns}
+    ${start_date}
+    ${end_date}
+    ${dropna}
+    ${skiprows}
+    ${index_type}
+    ${names}
+    ${clean}
+    ${float_format}
+    ${round_index}
+    ${source_units}
+    ${target_units}
+    ${print_input}
+    ${tablefmt}
     """
     tsutils.printiso(
         peak_detection(
@@ -915,6 +907,7 @@ def peak_detection_cli(
 
 
 @typic.al
+@tsutils.copy_doc(peak_detection_cli)
 def peak_detection(
     input_ts="-",
     columns=None,
@@ -956,34 +949,34 @@ def peak_detection(
 
     window = int(window)
     kwds = {}
-    if method == "rel":
-        func = _argrel
-        window = window / 2
-        if window == 0:
-            window = 1
-        kwds["window"] = int(window)
+    if method == "fft":
+        func = _peakdetect_fft
+        kwds["pad_len"] = int(pad_len)
+
     elif method == "minmax":
         func = _peakdetect
-        window = int(window / 2)
+        window //= 2
         if window == 0:
             window = 1
-        kwds["window"] = int(window)
-    elif method == "zero_crossing":
-        func = _peakdetect_zero_crossing
-        if not window % 2:
-            window = window + 1
-        kwds["window"] = int(window)
+        kwds["window"] = window
     elif method == "parabola":
         func = _peakdetect_parabola
         kwds["points"] = int(points)
+    elif method == "rel":
+        func = _argrel
+        window /= 2
+        if window == 0:
+            window = 1
+        kwds["window"] = window
     elif method == "sine":
         func = _peakdetect_sine
         kwds["points"] = int(points)
         kwds["lock_frequency"] = lock_frequency
-    elif method == "fft":  # currently would never be used.
-        func = _peakdetect_fft
-        kwds["pad_len"] = int(pad_len)
-
+    elif method == "zero_crossing":
+        func = _peakdetect_zero_crossing
+        if not window % 2:
+            window += 1
+        kwds["window"] = window
     tmptsd = tsd.copy()
     if extrema == "both":
         tmptsd.columns = [tsutils.renamer(i, "peak") for i in tsd.columns]
@@ -1012,6 +1005,3 @@ def peak_detection(
     tmptsd.index.name = "Datetime"
     tsd.index.name = "Datetime"
     return tsutils.return_input(print_input, tsd, tmptsd, suffix="")
-
-
-peak_detection.__doc__ = peak_detection_cli.__doc__
