@@ -22,16 +22,12 @@ def check_on_off(value):
         lowcase = value.lower()
         if lowcase == "off":
             return lowcase
-        elif lowcase == "on":
+        if lowcase == "on":
             return lowcase
-        else:
-            raise ValueError("Invalid value: " + str(value))
-    elif isinstance(value, bool):
-        if not value:
-            value = "off"
-        elif value:
-            value = "on"
+        raise ValueError(f"Invalid value: {str(value)}")
+    if isinstance(value, bool):
+        value = "on" if value else "off"
     else:
-        raise ValueError("Invalid value: " + str(value))
+        raise ValueError(f"Invalid value: {str(value)}")
 
     return value
