@@ -6,11 +6,12 @@ from tstoolbox import tsutils
 
 
 class TestMakeList(TestCase):
-    def test_make_list(self):
-        assert tsutils.make_list(None) == None
+    @staticmethod
+    def test_make_list():
+        assert tsutils.make_list(None) is None
         assert tsutils.make_list(1) == [1]
         assert tsutils.make_list(1.2) == [1.2]
-        assert tsutils.make_list("") == None
+        assert tsutils.make_list("") is None
         assert tsutils.make_list("1,2") == [1, 2]
         assert tsutils.make_list("2,") == [2, None]
         assert tsutils.make_list([1, 2, 3]) == [1, 2, 3]
@@ -20,6 +21,6 @@ class TestMakeList(TestCase):
         assert tsutils.make_list(["1", "er", "3"]) == [1, "er", 3]
         assert tsutils.make_list(["1", "", "5.6"]) == [1, None, 5.6]
         assert tsutils.make_list(["1", "None", "5.6"]) == [1, None, 5.6]
-        assert tsutils.make_list("None") == None
-        assert tsutils.make_list("") == None
+        assert tsutils.make_list("None") is None
+        assert tsutils.make_list("") is None
         assert tsutils.make_list("1.1,2.2,") == [1.1, 2.2, None]
