@@ -11,7 +11,6 @@ from pandas.testing import assert_frame_equal
 
 from tstoolbox import tstoolbox, tsutils
 
-
 output_peak_detection = tsutils.read_iso_ts(
     b"""Datetime,0,0::peak,0::valley
 2000-01-01 00:00:00,0,,
@@ -104,6 +103,9 @@ class TestPeakDetect(TestCase):
         out = tstoolbox.peak_detection(
             input_ts=self.ats, print_input=True, extrema="both"
         )
+        cols = list(out.columns)
+        cols[0] = 0
+        out.columns = cols
         assert_frame_equal(out, self.compare)
 
     def test_peak_minmax_direct(self):
@@ -115,6 +117,9 @@ class TestPeakDetect(TestCase):
             print_input=True,
             extrema="both",
         )
+        cols = list(out.columns)
+        cols[0] = 0
+        out.columns = cols
         assert_frame_equal(out, self.compare)
 
     def test_peak_zero_crossing_direct(self):
@@ -126,25 +131,24 @@ class TestPeakDetect(TestCase):
             print_input=True,
             extrema="both",
         )
+        cols = list(out.columns)
+        cols[0] = 0
+        out.columns = cols
         assert_frame_equal(out, self.compare)
 
-    #    def test_peak_parabola_direct(self):
-    #        out = tstoolbox.peak_detection(method='parabola',
-    #                                       input_ts=self.ats,
-    #                                       print_input=True,
-    #                                       extrema='both')
-    #        self.maxDiff = None
-    #        assert_frame_equal(out, self.compare)
-
     def test_peak_sine_direct(self):
         """Test peak detection API using the 'sine' method."""
         out = tstoolbox.peak_detection(
             method="sine", points=9, input_ts=self.ats, print_input=True, extrema="both"
         )
+        cols = list(out.columns)
+        cols[0] = 0
+        out.columns = cols
         assert_frame_equal(out, self.compare)
 
     # CLI...
-    def test_peak_rel_cli(self):
+    @staticmethod
+    def test_peak_rel_cli():
         """Test peak detection CLI using the default method."""
         args = 'tstoolbox peak_detection --extrema="both" --print_input=True'
         args = shlex.split(args)
@@ -154,7 +158,8 @@ class TestPeakDetect(TestCase):
         out = tsutils.read_iso_ts(out)
         assert_frame_equal(out, output_peak_detection)
 
-    def test_peak_minmax_cli(self):
+    @staticmethod
+    def test_peak_minmax_cli():
         """Test peak detection CLI using the minmax method."""
         args = (
             "tstoolbox peak_detection "
@@ -168,12 +173,12 @@ class TestPeakDetect(TestCase):
             args, stdout=subprocess.PIPE, stdin=subprocess.PIPE
         ).communicate(input=input_peak_detection)[0]
         out = tsutils.read_iso_ts(out)
-        # input_peak_detection.to_csv("input.csv")
         output_peak_detection.to_csv("output.csv")
         out.to_csv("out.csv")
         assert_frame_equal(out, output_peak_detection)
 
-    def test_peak_zero_crossing_cli(self):
+    @staticmethod
+    def test_peak_zero_crossing_cli():
         """Test peak detection CLI using the zero_crossing method."""
         args = (
             "tstoolbox peak_detection "
@@ -189,17 +194,8 @@ class TestPeakDetect(TestCase):
         out = tsutils.read_iso_ts(out)
         assert_frame_equal(out, output_peak_detection)
 
-    # def test_peak_parabola_cli(self):
-    #     args = ('tstoolbox peak_detection '
-    #             '--method="parabola" --extrema="both" --print_input=True')
-    #     args = shlex.split(args)
-    #     out = subprocess.Popen(args,
-    #         stdout=subprocess.PIPE,
-    #         stdin=subprocess.PIPE).communicate(input=input_peak_detection)[0]
-    #     self.maxDiff = None
-    #     self.assertEqual(out, output_peak_detection)
-
-    def test_peak_sine_cli(self):
+    @staticmethod
+    def test_peak_sine_cli():
         """Test peak detection CLI using the 'sine' method."""
         args = (
             "tstoolbox peak_detection "
