@@ -24,7 +24,7 @@ class TestPick(TestCase):
         )
         self.pick_multiple_direct = tsutils.memory_optimize(self.pick_multiple_direct)
 
-        self.pick_cli = capture.capture(tsutils._printiso, self.pick_multiple_direct)
+        self.pick_cli = capture.capture(tsutils.printiso, self.pick_multiple_direct)
 
     def test_pick(self):
         """Test the pick API by picking the 2nd then the 1st column.
