@@ -2,7 +2,6 @@
 
 import shlex
 import subprocess
-import sys
 from unittest import TestCase
 
 import pandas
@@ -129,3 +128,27 @@ class TestRead(TestCase):
         out = subprocess.Popen(args, stdout=subprocess.PIPE).communicate()[0]
         out = tsutils.read_iso_ts(out)
         assert_frame_equal(out, self.read_blanks)
+
+
+def test_read_xlsx():
+    """Test read API for xlsx"""
+    out = tstoolbox.read("tests/data_flow_stage.xlsx")
+    comp = tstoolbox.read("tests/data.wdm,2")
+    comp.columns = ["Lake Helen"]
+    assert_frame_equal(out, comp)
+
+
+def test_read_xlsx_sheet_name():
+    """Test read API for xlsx"""
+    out = tstoolbox.read("tests/data_flow_stage.xlsx,in")
+    comp = tstoolbox.read("tests/data.wdm,2")
+    comp.columns = ["in_Lake Helen"]
+    assert_frame_equal(out, comp)
+
+
+def test_read_xlsx_sheet_number():
+    """Test read API for xlsx"""
+    out = pandas.DataFrame(tstoolbox.read("tests/data_flow_stage.xlsx,0,in").iloc[:, 0])
+    comp = tstoolbox.read("tests/data.wdm,2")
+    comp.columns = ["0_Lake Helen"]
+    assert_frame_equal(out, comp)
