@@ -41,10 +41,10 @@ class TestRead(TestCase):
 
     def test_read_direct(self):
         """Test read API for single column - daily."""
-        out = tstoolbox.read("tests/data_simple_extra_rows.csv", skiprows=2)
+        out = tstoolbox.read("tests/data_simple_extra_rows.csv,skiprows=2")
         assert_frame_equal(out, self.read_direct)
 
     def test_read_direct_sparse(self):
         """Test read API for single column - daily."""
-        out = tstoolbox.read("tests/data_simple_extra_rows_sparse.csv", skiprows=[4, 6])
+        out = tstoolbox.read("tests/data_simple_extra_rows_sparse.csv,skiprows=[4,6]")
         assert_frame_equal(out, self.read_direct_sparse)
